ModuleRoute class
- Inheritance
-
- Object
- ModularRoute
- ModuleRoute
Constructors
-
ModuleRoute(String path, {required Module module, String? name, List<
RouteGuard> guards = const []})
Properties
-
guards
→ List<
RouteGuard> -
Guards que protegem todas as rotas deste módulo, avaliados após o registro
dos binds e em curto-circuito ("primeiro que barrar vence"). Veja
RouteGuard.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- module → Module
-
final
- name → String?
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited