Ponto de entrada para disparar eventos no bus global durante testes.
Encapsula ModularEvent.fire com um nome semântico para o contexto de testes, evitando importar o barrel principal só para disparar eventos.
Uso:
ModularEventBus.fire(PaymentProcessedEvent(MoneyAmount(100)));
await Future.delayed(Duration(milliseconds: 50));
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited